@@ -33,6 +33,13 @@ class RTDataUtils:
             rxn_code = row['rxn_code']
             yield self._rxn_data_utils.get_rxn_by_code(rxn_code)
 
+    def get_rt_by_rt_code(self, rt_code: str) -> RT:
+        query_df = self._rt_data_df.query(f"rt_code=='{rt_code}'")
+        if len(query_df) == 0:
+            return None
+        idx = query_df.index[0]
+        return RT(query_df.loc[idx])
+
 
 if __name__ == "__main__":
     pass
